summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohn Bowler <jbowler@acm.org>2014-12-14 18:49:53 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-12-14 19:17:56 -0600
commitd040886dc43b32bee82573226308c4b4d57527bd (patch)
treee9879669ccbd3fe77d8e312c381ff4909eda1a93
parent91f9e0370d8b6fa5b3710a19efbb68ed77208b5f (diff)
downloadlibpng-d040886dc43b32bee82573226308c4b4d57527bd.tar.gz
[libpng16] Revised handling of scripts/*.dfn; renamed them to scripts/*.c
-rw-r--r--ANNOUNCE6
-rw-r--r--CHANGES4
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am19
-rw-r--r--README2
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/def.c (renamed from scripts/def.dfn)6
-rw-r--r--scripts/intprefix.c (renamed from scripts/intprefix.dfn)6
-rw-r--r--scripts/pnglibconf.dfa2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
-rw-r--r--scripts/prefix.c (renamed from scripts/prefix.dfn)6
-rw-r--r--scripts/sym.c (renamed from scripts/sym.dfn)8
-rw-r--r--scripts/symbols.c (renamed from scripts/symbols.dfn)14
-rw-r--r--scripts/vers.c (renamed from scripts/vers.dfn)6
23 files changed, 67 insertions, 64 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 7d16a083f..dc9b488c6 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.16beta02 - December 14, 2014
+Libpng 1.6.16beta02 - December 15, 2014
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -31,7 +31,9 @@ Version 1.6.16beta01 [December 14, 2014]
Revised Makefile.am and scripts/symbols.dfn to work with MinGW/MSYS
(Bob Friesenhahn).
-Version 1.6.16beta02 [December 14, 2014]
+Version 1.6.16beta02 [December 15, 2014]
+ Revised Makefile.am and scripts/*.dfn again to work with MinGW/MSYS
+ (renamed scripts/*.dfn to scripts/*.c) (John Bowler).
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index cd70a5bdb..cb0cc3e13 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5105,7 +5105,9 @@ Version 1.6.16beta01 [December 14, 2014]
Revised Makefile.am and scripts/symbols.dfn to work with MinGW/MSYS
(Bob Friesenhahn).
-Version 1.6.16beta02 [December 14, 2014]
+Version 1.6.16beta02 [December 15, 2014]
+ Revised Makefile.am and scripts/*.dfn again to work with MinGW/MSYS
+ (renamed scripts/*.dfn to scripts/*.c) (John Bowler).
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/LICENSE b/LICENSE
index 1efded6fd..bf81900f5 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.16beta02, December 14, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.16beta02, December 15, 2014, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 14, 2014
+December 15, 2014
diff --git a/Makefile.am b/Makefile.am
index 61c6b6e98..a9e8d3c3c 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -129,7 +129,7 @@ EXTRA_DIST= \
$(TESTS) $(XFAIL_TESTS) tests/pngstest \
CMakeLists.txt example.c libpng-manual.txt
-SCRIPT_CLEANFILES=scripts/*.out scripts/*.chk scripts/pnglibconf.dfn
+SCRIPT_CLEANFILES=scripts/*.out scripts/*.chk scripts/pnglibconf.c
CLEANFILES= *.tf? pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc \
libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers libpng.sym \
@@ -152,7 +152,7 @@ AM_CFLAGS = ${PNG_COPTS}
# checks for this and sets DFNCPP appropriately.
DFNCPP = @DFNCPP@
-SUFFIXES = .chk .dfn .out
+SUFFIXES = .chk .out
$(PNGLIB_BASENAME).pc: libpng.pc
cp libpng.pc $@
@@ -237,18 +237,17 @@ if DO_PNG_PREFIX
SYMBOL_CFLAGS += -DPNG_PREFIX='@PNG_PREFIX@'
endif
-.dfn.out:
- rm -f $@ $*.c $*.tf[12]
+.c.out:
+ rm -f $@ $*.tf[12]
test -d scripts || mkdir scripts || test -d scripts
- cp "$<" $*.c
$(DFNCPP) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES)\
- $(CPPFLAGS) $(SYMBOL_CFLAGS) $*.c > $*.tf1
+ $(CPPFLAGS) $(SYMBOL_CFLAGS) $< > $*.tf1
$(AWK) -f "${srcdir}/scripts/dfn.awk" out="$*.tf2" $*.tf1 1>&2
- rm -f $*.c $*.tf1
+ rm -f $*.tf1
mv $*.tf2 $@
-# The .dfn file for pnglibconf.h is machine generated
-pnglibconf.dfn: scripts/pnglibconf.dfa scripts/options.awk pngconf.h pngusr.dfa $(DFA_XTRA)
+# The .c file for pnglibconf.h is machine generated
+pnglibconf.c: scripts/pnglibconf.dfa scripts/options.awk pngconf.h pngusr.dfa $(DFA_XTRA)
rm -f $@ $*.tf[45]
$(AWK) -f ${srcdir}/scripts/options.awk out=$*.tf4 version=search\
${srcdir}/pngconf.h ${srcdir}/scripts/pnglibconf.dfa\
@@ -268,7 +267,7 @@ scripts/symbols.chk: scripts/checksym.awk scripts/symbols.def scripts/symbols.ou
# used on demand to regenerate the standard header, CPPFLAGS should
# be empty - no non-standard defines
-scripts/pnglibconf.dfn: scripts/pnglibconf.dfa scripts/options.awk pngconf.h
+scripts/pnglibconf.c: scripts/pnglibconf.dfa scripts/options.awk pngconf.h
rm -f $@ pnglibconf.tf[67]
test -z "$(CPPFLAGS)"
echo "com @PNGLIB_VERSION@ STANDARD API DEFINITION" |\
diff --git a/README b/README
index 8abe905bc..1fdabaa98 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.16beta02 - December 14, 2014 (shared library 16.0)
+README for libpng version 1.6.16beta02 - December 15, 2014 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index d619550c6..a0a6462e3 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.16beta02 - December 14, 2014
+ libpng version 1.6.16beta02 - December 15, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.16beta02 - December 14, 2014
+ libpng versions 0.97, January 1998, through 1.6.16beta02 - December 15, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5277,7 +5277,7 @@ Other rules can be inferred by inspecting the libpng source.
XVI. Y2K Compliance in libpng
-December 14, 2014
+December 15, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index 060a25724..9dbcddec1 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "December 14, 2014"
+.TH LIBPNG 3 "December 15, 2014"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.16beta02
.SH SYNOPSIS
@@ -504,7 +504,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.16beta02 - December 14, 2014
+ libpng version 1.6.16beta02 - December 15, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -515,7 +515,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.16beta02 - December 14, 2014
+ libpng versions 0.97, January 1998, through 1.6.16beta02 - December 15, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5781,7 +5781,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XVI. Y2K Compliance in libpng
-December 14, 2014
+December 15, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -6093,7 +6093,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.16beta02 - December 14, 2014:
+Libpng version 1.6.16beta02 - December 15, 2014:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6116,7 +6116,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.16beta02, December 14, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.16beta02, December 15, 2014, are
Copyright (c) 2004,2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -6215,7 +6215,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 14, 2014
+December 15, 2014
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 934f0ed18..e4cb92d30 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "December 14, 2014"
+.TH LIBPNGPF 3 "December 15, 2014"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.16beta02
(private functions)
diff --git a/png.5 b/png.5
index e3fa7c866..5299a658d 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "December 14, 2014"
+.TH PNG 5 "December 15, 2014"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 3c1cf72c9..a8de26dc0 100644
--- a/png.c
+++ b/png.c
@@ -769,13 +769,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.16beta02 - December 14, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.6.16beta02 - December 15, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.16beta02 - December 14, 2014\
+ return "libpng version 1.6.16beta02 - December 15, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 81b9feb9f..47979b9b3 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.16beta02,December 14, 2014
+ * libpng version 1.6.16beta02,December 15, 2014
*
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index ef3ff8129..9234683b5 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.16beta02 - December 14, 2014
+libpng version 1.6.16beta02 - December 15, 2014
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 965cf158a..28a59f178 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.16beta02 - December 14, 2014
+ * libpng version 1.6.16beta02 - December 15, 2014
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 8423ed13a..8461f34e2 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.6.16beta02 - December 14, 2014
+Makefiles for libpng version 1.6.16beta02 - December 15, 2014
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/def.dfn b/scripts/def.c
index b888d27dc..868a113f0 100644
--- a/scripts/def.dfn
+++ b/scripts/def.c
@@ -1,7 +1,7 @@
-/* def.dfn - define format of libpng.def
+/* def.c - define format of libpng.def
*
- * Last changed in libpng version 1.5.7 [December 15, 2011]
- * Copyright (c) 2010-2011 Glenn Randers-Pehrson
+ * Last changed in libpng version 1.6.16 [(PENDING RELEASE)]
+ * Copyright (c) 2010-2014 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/scripts/intprefix.dfn b/scripts/intprefix.c
index fa59f88e9..387dd10d6 100644
--- a/scripts/intprefix.dfn
+++ b/scripts/intprefix.c
@@ -1,8 +1,8 @@
-/* intprefix.dfn - generate an unprefixed internal symbol list
+/* intprefix.c - generate an unprefixed internal symbol list
*
- * Last changed in libpng version 1.6.0 [January 30, 2012]
- * Copyright (c) 2012 Glenn Randers-Pehrson
+ * Last changed in libpng version 1.6.16 [(PENDING RELEASE)]
+ * Copyright (c) 2012-2014 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/scripts/pnglibconf.dfa b/scripts/pnglibconf.dfa
index 2744b6ba5..d98d27437 100644
--- a/scripts/pnglibconf.dfa
+++ b/scripts/pnglibconf.dfa
@@ -303,7 +303,7 @@ option BENIGN_READ_ERRORS requires BENIGN_ERRORS
option MNG_FEATURES
# Arithmetic options, the first is the big switch that chooses between internal
-# floating and fixed point arithmetic implementations - it does not affect an
+# floating and fixed point arithmetic implementations - it does not affect any
# APIs. The second two (the _POINT settings) switch off individual APIs.
#
# Prior to libpng 1.6.8 one of the API (_POINT) variants had to be selected. At
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 87ac56ac9..77cee482d 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -2,7 +2,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.16beta02 - December 14, 2014 */
+/* Libpng version 1.6.16beta02 - December 15, 2014 */
/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/scripts/prefix.dfn b/scripts/prefix.c
index 0997310c5..26a2b1595 100644
--- a/scripts/prefix.dfn
+++ b/scripts/prefix.c
@@ -1,8 +1,8 @@
-/* prefix.dfn - generate an unprefixed symbol list
+/* prefix.c - generate an unprefixed symbol list
*
- * Last changed in libpng version 1.6.0 [January 30, 2012]
- * Copyright (c) 2012 Glenn Randers-Pehrson
+ * Last changed in libpng version 1.6.16 [(PENDING RELEASE)]
+ * Copyright (c) 2012-2014 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/scripts/sym.dfn b/scripts/sym.c
index ee9fba25b..94b7b4b59 100644
--- a/scripts/sym.dfn
+++ b/scripts/sym.c
@@ -1,8 +1,8 @@
-/* sym.dfn - define format of libpng.sym
+/* sym.c - define format of libpng.sym
*
- * Last changed in libpng version 1.5.0 [January 6, 2011]
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson
+ * Last changed in libpng version 1.6.16 [(PENDING RELEASE)]
+ * Copyright (c) 1998-2014 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
@@ -12,4 +12,4 @@
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
-#include "png.h"
+#include "../png.h"
diff --git a/scripts/symbols.dfn b/scripts/symbols.c
index 57266bf6a..910494a0d 100644
--- a/scripts/symbols.dfn
+++ b/scripts/symbols.c
@@ -1,8 +1,8 @@
-/* symbols.dfn - find all exported symbols
+/* symbols.c - find all exported symbols
*
- * Last changed in libpng version 1.5.0 [January 6, 2011]
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson
+ * Last changed in libpng version 1.6.16 [(PENDING RELEASE)]
+ * Copyright (c) 1998-2014 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
@@ -26,8 +26,8 @@
/* Read the defaults, but use scripts/pnglibconf.h.prebuilt; the 'standard'
* header file.
*/
-#include "scripts/pnglibconf.h.prebuilt"
-#include "png.h"
+#include "pnglibconf.h.prebuilt"
+#include "../png.h"
/* Some things are turned off by default. Turn these things
* on here (by hand) to get the APIs they expose and validate
@@ -45,7 +45,7 @@
#define PNG_SET_OPTION_SUPPORTED
#undef PNG_H
-#include "png.h"
+#include "../png.h"
/* Finally there are a couple of places where option support
* actually changes the APIs revealed using a #if/#else/#endif
@@ -55,4 +55,4 @@
#undef PNG_ERROR_TEXT_SUPPORTED /* Exposes unsupported APIs */
#undef PNG_H
-#include "png.h"
+#include "../png.h"
diff --git a/scripts/vers.dfn b/scripts/vers.c
index 61ba7d80b..0685de3ba 100644
--- a/scripts/vers.dfn
+++ b/scripts/vers.c
@@ -1,8 +1,8 @@
-/* vers.dfn - define format of libpng.vers
+/* vers.c - define format of libpng.vers
*
- * Last changed in libpng version 1.5.0 [January 6, 2011]
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson
+ * Last changed in libpng version 1.6.16 [(PENDING RELEASE)]
+ * Copyright (c) 1998-2014 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/png.h b/png.h
index 197442d53..c61474937 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.16beta02, December 14, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.16beta02, December 14, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -241,7 +241,7 @@
*
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.16beta02, December 14, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.16beta02, December 15, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -353,7 +353,7 @@
* Y2K compliance in libpng:
* =========================
*
- * December 14, 2014
+ * December 15, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -423,7 +423,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.6.16beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.16beta02 - December 14, 2014\n"
+ " libpng version 1.6.16beta02 - December 15, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.16beta02, December 14, 2014
+ * libpng version 1.6.16beta02, December 15, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.16beta02, December 14, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.16beta02, December 15, 2014: Glenn
* See also "Contributing Authors", below.
*